@@ -14,16 +14,13 @@ fit <- stan_crm(outcomes, skeleton = skeleton, target = target,
 fit
 
 ## ---- warning=FALSE, message=FALSE---------------------------------------
-library(tidyr)
 library(dplyr)
+library(tidybayes)
 
-prob_tox_samp <- as.data.frame(fit, 'prob_tox')
-prob_tox_samp_tall <- prob_tox_samp %>%
-  gather(Label, ProbTox) %>%
-  mutate(
-    DoseLevel = rep(1:ncol(prob_tox_samp), each = nrow(prob_tox_samp)),
-    Draw = rep(1:nrow(prob_tox_samp), times = ncol(prob_tox_samp))
-  )
+prob_tox_samp_tall <- fit %>% 
+  gather_draws(prob_tox[dose]) %>% 
+  rename(prob_dlt = .value) %>% 
+  ungroup
 
 ## ------------------------------------------------------------------------
 prob_tox_samp_tall %>% head(10)
@@ -32,61 +29,63 @@ prob_tox_samp_tall %>% head(10)
 library(ggplot2)
 
 prob_tox_samp_tall %>% 
-  ggplot(aes(x = DoseLevel, y = ProbTox, group = DoseLevel)) +
+  ggplot(aes(x = dose, y = prob_dlt, group = dose)) +
   geom_boxplot() + 
   ylim(0, 1) + 
-  labs(title = 'boxplot of Pr(DLT) under CRM')
+  labs(title = 'Boxplot of Prob(DLT) under CRM')
 
 ## ---- fig.width=7, fig.height=7------------------------------------------
 prob_tox_samp_tall %>% 
-  ggplot(aes(x = DoseLevel, y = ProbTox, group = DoseLevel)) +
+  ggplot(aes(x = dose, y = prob_dlt, group = dose)) +
   geom_violin(fill = 'orange') + 
   ylim(0, 1) + 
-  labs(title = 'violin plot of Pr(DLT) under CRM')
+  labs(title = 'Violin plot of Prob(DLT) under CRM')
 
 ## ---- fig.width=7, fig.height=7, message=FALSE---------------------------
 library(ggridges)
 
 prob_tox_samp_tall %>% 
-  mutate(DoseLevel = factor(DoseLevel)) %>% 
-  ggplot(aes(x = ProbTox, y = DoseLevel, fill = DoseLevel)) +
+  mutate(dose = factor(dose)) %>% 
+  ggplot(aes(x = prob_dlt, y = dose, fill = dose)) +
   geom_density_ridges() + 
   theme(legend.position = 'none') +
-  labs(title = 'joyplot of Pr(DLT) under CRM') + 
+  labs(title = 'Joyplot of Prob(DLT) under CRM') + 
   theme(legend.position = 'bottom')
 
 ## ---- fig.width=7, fig.height=7, message=FALSE---------------------------
-prob_tox_samp_tall %>% 
-  filter(Draw <= 200) -> prob_tox_subset
+prob_tox_samp_tall  %>% 
+  group_by(.draw) %>% 
+  summarise(mtd = dose[which.min(abs(prob_dlt - target))]) %>% 
+  mutate(mtd = factor(mtd)) -> mtd_candidates
 
-prob_tox_subset %>% 
-  left_join(
-    prob_tox_subset %>% 
-      group_by(Draw) %>% 
-      summarise(MTD = which.min(abs(ProbTox - target)) %>% factor()),
-    by = 'Draw') %>% 
-  ggplot(aes(x = DoseLevel, y = ProbTox, group = Draw)) +
-  geom_line(aes(col = MTD), alpha = 0.5) + 
+prob_tox_samp_tall %>% 
+  left_join(mtd_candidates, by = '.draw') %>% 
+  filter(.draw <= 200) %>% 
+  ggplot(aes(x = dose, y = prob_dlt, group = .draw)) +
+  geom_line(aes(col = mtd), alpha = 0.5) + 
   geom_hline(yintercept = target, col = 'red', linetype = 'dashed') + 
-  labs(title = 'Identify of MTD is shrouded in mystery') +
+  labs(title = 'The identify of the MTD is still shrouded in mystery', 
+       y = 'Prob(DLT)', col = 'MTD') +
   theme(legend.position = 'bottom')
 
 ## ---- fig.width=7, fig.height=7, message=FALSE, warning=FALSE------------
-apply(prob_tox_samp, 1, function(x) which.min(abs(x - target))) %>% 
-  data.frame(MTD = factor(.)) %>% 
-  count(MTD) %>% 
-  mutate(ProbMTD = n / sum(n)) %>% 
-  ggplot(aes(x = MTD, y = ProbMTD, fill = MTD)) + 
+mtd_candidates %>% 
+  count(mtd) %>% 
+  mutate(prob_mtd = n / sum(n)) %>% 
+  ggplot(aes(x = mtd, y = prob_mtd, fill = mtd)) + 
   geom_col() +
+  labs(x = 'MTD') +
   theme(legend.position = 'bottom')
 
 ## ---- fig.width=7, fig.height=7------------------------------------------
-colMeans(prob_tox_samp > target) %>% 
-  data.frame(ProbToxic = ., DoseLevel = 1:length(skeleton)) %>%
-  ggplot(aes(x = DoseLevel, y = ProbToxic, fill = ProbToxic)) + 
+fit %>% 
+  gather_draws(prob_tox[dose]) %>% 
+  group_by(dose) %>% 
+  summarise(prob_too_toxic = mean(.value > target)) %>%
+  ggplot(aes(x = dose, y = prob_too_toxic, fill = dose)) + 
   geom_col() + 
   scale_fill_gradient(low="green", high="red") + 
   labs(title = 'Posterior probability that each dose is too toxic',
-       y = 'Prob(Tox > target)', fill = 'Prob too toxic') +
+       y = 'Prob(DLT risk > target)', fill = 'Probability dose is too toxic') +
   theme(legend.position = 'bottom')
 
